pub struct SeaOrmConfig {
pub uri: String,
pub enable_logging: bool,
pub min_connections: u32,
pub max_connections: u32,
pub connect_timeout: Option<u64>,
pub idle_timeout: Option<u64>,
pub acquire_timeout: Option<u64>,
}Fields
uri: StringThe URI for connecting to the database. For example:
- Postgres:
postgres://root:12341234@localhost:5432/myapp_development - Sqlite:
sqlite://db.sqlite?mode=rwc
enable_logging: boolEnable SQLx statement logging
min_connections: u32Minimum number of connections for a pool
max_connections: u32Maximum number of connections for a pool
connect_timeout: Option<u64>Set the timeout duration when acquiring a connection
idle_timeout: Option<u64>Set a maximum idle duration for individual connections. Any connection that remains in the idle queue longer than this will be closed. For usage-based database server billing, this can be a cost saver.
acquire_timeout: Option<u64>Set the timeout for acquiring a connection